#!/bin/sh
#--------------------------------------------------------------------
# mkrootfs.sh
#--------------------------------------------------------------------

# mkroofs.sh should be excuted at ramdisk-boot mode

IS_INITRD_BOOT=`cat /proc/cmdline | grep -c "initrd="`
if [ $IS_INITRD_BOOT -ne 1 ]; then
	echo "mkrootfs.sh should be excuted at ramdisk-boot mode"
	exit 0
fi

FWUPDATEPOST_FLAG=/fwupdate_done
FWUPDATE_LOG=/fwupdate.log

if [ -f $FWUPDATEPOST_FLAG ]; then
	echo "Already excuted $0"
	exit 0
fi

PATH=/sbin:/usr/sbin:/bin:/usr/bin:$PATH
export PATH

. /etc/init.d/fwup-function

write_firmup_state 65 "Make rfs ..."

#check 1st argument, if exist, run argv1
if [ $# -eq 1 ]; then
	[ -x $1 ] && $1
fi

SYFT_SIZE=0

function get_syft_length()
{
	SYFT_ID=$1
#	echo syft id $SYFT_ID
	SIZE=`/usr/sbin/fuc -d | /bin/grep ^${SYFT_ID} | /usr/bin/awk '{print $3}' | /bin/sed 's/0x//g'`
	SYFT_SIZE=$((16#${SIZE}))	
#	echo syft size $SIZE
}

function write_log_msg()
{
	echo >> $FWUPDATE_LOG
	date >> $FWUPDATE_LOG
	echo "$1" >> $FWUPDATE_LOG
}

function cmd_out_log()
{
	echo >> $FWUPDATE_LOG
	date >> $FWUPDATE_LOG
	$1 >> $FWUPDATE_LOG
}

echo
echo "Start making the new rootfs ..."

write_log_msg "Start mkrootfs.sh"


CI_MTD=/dev/mtd5
CI_IMG=/ci.tar.gz


cmd_out_log /bin/mount
cmd_out_log "/bin/df -h"

cd /mnt/rfs

# make root fs
# untar repository files

REPO_DIR=/mnt/repo
RF_LIST=`ls $REPO_DIR/rf_tg*rs*tar.gz $REPO_DIR/rf_tg*w[12]*tar.gz  $REPO_DIR/rf_tg[12]-*tar.gz`

# extract rf's
for RF in $RF_LIST
do
	echo
	echo "Extract $RF"

	tar xzf ${RF}

	/bin/sync
done

write_firmup_state 70 "Make rfs ... Done"


write_firmup_state 75 "Restore ci ..."


# Make default config
DEF_CFG=etc/default_conf.tgz
echo -n "Make default config  "
. etc/sysconfig/_conf.list
/bin/tar czf $DEF_CFG $FILES_TO_COMPRESS
echo "[ Done ]"
write_log_msg "Make default config"

# Config Image
##get_syft_length 02
##CI_SIZE=$SYFT_SIZE
##echo ci size $CI_SIZE
/usr/sbin/nanddump -o -B -f $CI_IMG $CI_MTD
/bin/gunzip -t $CI_IMG
if [ $? -eq 0 ]; then
	write_log_msg "Extract CI"
	/bin/tar xzf $CI_IMG
#	cmd_out_log "/bin/df -h"
fi
rm $CI_IMG
sync

write_firmup_state 80 "Restore ci ... Done"

# FES
RF_LIST=`ls $REPO_DIR/rf_tg*fe*tar.gz`

# extract rf's
for RF in $RF_LIST
do
	echo
	echo "Extract $RF"

	tar xzf ${RF}

	/bin/sync
done


write_firmup_state 85 "Change ki ..."

# run additional script in rf's
EXTRA_SCRIPT=/mnt/rfs/opt/nss/bin/mkrootfspost.sh
if [ -x "$EXTRA_SCRIPT" ]; then
	echo
	echo	"Run the additional script."
	echo

	$EXTRA_SCRIPT
fi


# make bootmode as normal boot
#/usr/sbin/fuc -sh sft-config offset=19 data=0
BOOTMODE_TMP=/bootmode.bin
echo -n -e \\x00\\x00\\x00\\x00 > $BOOTMODE_TMP
/usr/sbin/flash_eraseall /dev/mtd9
/usr/sbin/nandwrite -p /dev/mtd9 $BOOTMODE_TMP


write_firmup_state 90 "Change ki ... Done"


/bin/touch $FWUPDATEPOST_FLAG


write_log_msg "End of fwupdatepost.sh"

# wait for web-polling
sleep 6

exit 0
